@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -78,44 +78,88 @@ gpm_get_timestring (guint time_secs)
 	return timestring;
 }
 
+/**
+ * gpm_icon_policy_from_string:
+ **/
 GpmIconPolicy
-gpm_tray_icon_mode_from_string (const gchar *str)
+gpm_icon_policy_from_string (const gchar *policy)
 {
-	if (str == NULL) {
+	if (policy == NULL)
 		return GPM_ICON_POLICY_NEVER;
-	}
-
-	if (strcmp (str, "always") == 0) {
+	if (g_strcmp0 (policy, "always") == 0)
 		return GPM_ICON_POLICY_ALWAYS;
-	} else if (strcmp (str, "present") == 0) {
+	if (g_strcmp0 (policy, "present") == 0)
 		return GPM_ICON_POLICY_PRESENT;
-	} else if (strcmp (str, "charge") == 0) {
+	if (g_strcmp0 (policy, "charge") == 0)
 		return GPM_ICON_POLICY_CHARGE;
-	} else if (strcmp (str, "critical") == 0) {
+	if (g_strcmp0 (policy, "low") == 0)
+		return GPM_ICON_POLICY_LOW;
+	if (g_strcmp0 (policy, "critical") == 0)
 		return GPM_ICON_POLICY_CRITICAL;
-	} else if (strcmp (str, "never") == 0) {
+	if (g_strcmp0 (policy, "never") == 0)
 		return GPM_ICON_POLICY_NEVER;
-	} else {
-		return GPM_ICON_POLICY_NEVER;
-	}
+	return GPM_ICON_POLICY_NEVER;
 }
 
+/**
+ * gpm_icon_policy_to_string:
+ **/
 const gchar *
-gpm_tray_icon_mode_to_string (GpmIconPolicy mode)
+gpm_icon_policy_to_string (GpmIconPolicy policy)
 {
-	if (mode == GPM_ICON_POLICY_ALWAYS) {
+	if (policy == GPM_ICON_POLICY_ALWAYS)
 		return "always";
-	} else if (mode == GPM_ICON_POLICY_PRESENT) {
+	if (policy == GPM_ICON_POLICY_PRESENT)
 		return "present";
-	} else if (mode == GPM_ICON_POLICY_CHARGE) {
+	if (policy == GPM_ICON_POLICY_CHARGE)
 		return "charge";
-	} else if (mode == GPM_ICON_POLICY_CRITICAL) {
+	if (policy == GPM_ICON_POLICY_LOW)
+		return "low";
+	if (policy == GPM_ICON_POLICY_CRITICAL)
 		return "critical";
-	} else if (mode == GPM_ICON_POLICY_NEVER) {
+	if (policy == GPM_ICON_POLICY_NEVER)
 		return "never";
-	} else {
-		return "never";
-	}
+	return "never";
+}
+
+/**
+ * gpm_action_policy_from_string:
+ **/
+GpmActionPolicy
+gpm_action_policy_from_string (const gchar *policy)
+{
+	if (policy == NULL)
+		return GPM_ACTION_POLICY_NOTHING;
+	if (g_strcmp0 (policy, "blank") == 0)
+		return GPM_ACTION_POLICY_BLANK;
+	if (g_strcmp0 (policy, "shutdown") == 0)
+		return GPM_ACTION_POLICY_SHUTDOWN;
+	if (g_strcmp0 (policy, "suspend") == 0)
+		return GPM_ACTION_POLICY_SUSPEND;
+	if (g_strcmp0 (policy, "hibernate") == 0)
+		return GPM_ACTION_POLICY_HIBERNATE;
+	if (g_strcmp0 (policy, "interactive") == 0)
+		return GPM_ACTION_POLICY_INTERACTIVE;
+	return GPM_ACTION_POLICY_NOTHING;
+}
+
+/**
+ * gpm_action_policy_to_string:
+ **/
+const gchar *
+gpm_action_policy_to_string (GpmActionPolicy policy)
+{
+	if (policy == GPM_ACTION_POLICY_BLANK)
+		return "blank";
+	if (policy == GPM_ACTION_POLICY_SHUTDOWN)
+		return "shutdown";
+	if (policy == GPM_ACTION_POLICY_SUSPEND)
+		return "suspend";
+	if (policy == GPM_ACTION_POLICY_HIBERNATE)
+		return "hibernate";
+	if (policy == GPM_ACTION_POLICY_INTERACTIVE)
+		return "interactive";
+	return "nothing";
 }
 
 /**
@@ -126,53 +170,23 @@ void
 gpm_help_display (const gchar *link_id)
 {
 	GError *error = NULL;
-	char *command;
-	const char *lang;
-	char *uri = NULL;
-	GdkScreen *gscreen;
+	gchar *uri;
 
-	int i;
+	if (link_id != NULL)
+		uri = g_strconcat ("ghelp:gnome-power-manager?", link_id, NULL);
+	else
+		uri = g_strdup ("ghelp:gnome-power-manager");
 
-	const char * const * langs = g_get_language_names ();
+	gtk_show_uri (NULL, uri, GDK_CURRENT_TIME, &error);
 
-	for (i = 0; langs[i]; i++) {
-		lang = langs[i];
-		if (strchr (lang, '.')) {
-			continue;
-		}
-
-		uri = g_build_filename(DATADIR,
-				       "/gnome/help/gnome-power-manager/",
-					lang,
-				       "/gnome-power-manager.xml",
-					NULL);
-					
-		if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
-                    break;
-		}
-	}
-	
-	if (link_id) {
-		command = g_strconcat ("gnome-open ghelp://", uri, "?", link_id, NULL);
-	} else {
-		command = g_strconcat ("gnome-open ghelp://", uri,  NULL);
-	}
-
-	gscreen = gdk_screen_get_default();
-	gdk_spawn_command_line_on_screen (gscreen, command, &error);
 	if (error != NULL) {
 		GtkWidget *d;
-
-		d = gtk_message_dialog_new(NULL,
-				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-				"%s", error->message);
-		gtk_dialog_run(GTK_DIALOG(d));
-		gtk_widget_destroy(d);
-		g_error_free(error);
+		d = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					    GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", error->message);
+		gtk_dialog_run (GTK_DIALOG(d));
+		gtk_widget_destroy (d);
+		g_error_free (error);
 	}
-
-	g_free (command);
 	g_free (uri);
 }
 
@@ -183,11 +197,11 @@ gpm_help_display (const gchar *link_id)
 #include "egg-test.h"
 
 void
-gpm_common_test (EggTest *test)
+gpm_common_test (gpointer data)
 {
-	if (egg_test_start (test, "GpmCommon") == FALSE) {
+	EggTest *test = (EggTest *) data;
+	if (egg_test_start (test, "GpmCommon") == FALSE)
 		return;
-	}
 
 	egg_test_end (test);
 }
